@@ -6,7 +6,7 @@ from mir.commands import base
 from mir.protos import mir_command_pb2 as mirpb
 from mir.tools import checker, class_ids
 from mir.tools import mir_repo_utils, mir_storage_ops, revs_parser
-from mir.tools.annotations import filter_mirdatas_by_asset_ids
+from mir.tools.annotations import anno_type_from_str, filter_mirdatas_by_asset_ids
 from mir.tools.code import MirCode
 from mir.tools.command_run_in_out import command_run_in_out
 from mir.tools.errors import MirRuntimeError
@@ -18,7 +18,8 @@ class CmdFilter(base.BaseCommand):
     @staticmethod
     @command_run_in_out
     def run_with_args(mir_root: str, label_storage_file: str, in_cis: str, ex_cis: str,
-                      src_revs: str, dst_rev: str, work_dir: str) -> int:  # type: ignore
+                      filter_anno_src: "mirpb.AnnotationType.V", src_revs: str, dst_rev: str,
+                      work_dir: str) -> int:  # type: ignore
         src_typ_rev_tid = revs_parser.parse_single_arg_rev(src_revs, need_tid=False)
         dst_typ_rev_tid = revs_parser.parse_single_arg_rev(dst_rev, need_tid=True)
 
@@ -46,7 +47,8 @@ class CmdFilter(base.BaseCommand):
                        mir_annotations=mir_annotations,
                        label_storage_file=label_storage_file,
                        in_cis=in_cis,
-                       ex_cis=ex_cis)
+                       ex_cis=ex_cis,
+                       filter_anno_src=filter_anno_src)
 
         logging.info("matched: %d, overriding current mir repo", len(mir_metadatas.attributes))
 
@@ -73,13 +75,15 @@ class CmdFilter(base.BaseCommand):
 
     def run(self) -> int:
         logging.debug("command filter: %s", self.args)
-        return CmdFilter.run_with_args(mir_root=self.args.mir_root,
-                                       label_storage_file=self.args.label_storage_file,
-                                       in_cis=self.args.in_cis,
-                                       ex_cis=self.args.ex_cis,
-                                       src_revs=self.args.src_revs,
-                                       dst_rev=self.args.dst_rev,
-                                       work_dir=self.args.work_dir)
+        return CmdFilter.run_with_args(
+            mir_root=self.args.mir_root,
+            label_storage_file=self.args.label_storage_file,
+            in_cis=self.args.in_cis,
+            ex_cis=self.args.ex_cis,
+            filter_anno_src=anno_type_from_str(self.args.filter_anno_src),
+            src_revs=self.args.src_revs,
+            dst_rev=self.args.dst_rev,
+            work_dir=self.args.work_dir)
 
 
 def _class_ids_set_from_str(preds_str: str, cls_mgr: class_ids.UserLabels) -> Set[int]:
@@ -96,7 +100,7 @@ def _class_ids_set_from_str(preds_str: str, cls_mgr: class_ids.UserLabels) -> Se
 
 
 def _include_exclude_match(asset_ids_set: Set[str], mir_annotations: mirpb.MirAnnotations, in_cis_set: Set[int],
-                           ex_cis_set: Set[int]) -> Set[str]:
+                           ex_cis_set: Set[int], filter_anno_src: "mirpb.AnnotationType.V") -> Set[str]:
     # if don't need include match, returns all
     need_no_include = not in_cis_set
     need_no_exclude = not ex_cis_set
@@ -106,7 +110,11 @@ def _include_exclude_match(asset_ids_set: Set[str], mir_annotations: mirpb.MirAn
         pred = mir_annotations.prediction.image_annotations.get(asset_id, mirpb.SingleImageAnnotations())
         gt = mir_annotations.ground_truth.image_annotations.get(asset_id, mirpb.SingleImageAnnotations())
 
-        cids = {v.class_id for v in pred.boxes} | {v.class_id for v in gt.boxes}
+        cids = set()
+        if filter_anno_src in {mirpb.AnnotationType.AT_ANY, mirpb.AnnotationType.AT_GT}:
+            cids.update({v.class_id for v in gt.boxes})
+        elif filter_anno_src in {mirpb.AnnotationType.AT_ANY, mirpb.AnnotationType.AT_PRED}:
+            cids.update({v.class_id for v in pred.boxes})
         if (need_no_include or cids & in_cis_set) and (need_no_exclude or not (cids & ex_cis_set)):
             filtered_asset_ids_set.add(asset_id)
 
@@ -114,7 +122,7 @@ def _include_exclude_match(asset_ids_set: Set[str], mir_annotations: mirpb.MirAn
 
 
 def filter_with_pb(mir_metadatas: mirpb.MirMetadatas, mir_annotations: mirpb.MirAnnotations, label_storage_file: str,
-                   in_cis: str, ex_cis: str) -> None:
+                   in_cis: str, ex_cis: str, filter_anno_src: "mirpb.AnnotationType.V") -> None:
     in_cis = in_cis.strip().lower() if in_cis else ''
     ex_cis = ex_cis.strip().lower() if ex_cis else ''
     if not in_cis and not ex_cis:
@@ -127,7 +135,8 @@ def filter_with_pb(mir_metadatas: mirpb.MirMetadatas, mir_annotations: mirpb.Mir
     asset_ids_set = _include_exclude_match(asset_ids_set=set(mir_metadatas.attributes.keys()),
                                            mir_annotations=mir_annotations,
                                            in_cis_set=in_cis_set,
-                                           ex_cis_set=ex_cis_set)
+                                           ex_cis_set=ex_cis_set,
+                                           filter_anno_src=filter_anno_src)
 
     filter_mirdatas_by_asset_ids(mir_metadatas=mir_metadatas,
                                  mir_annotations=mir_annotations,
@@ -141,6 +150,13 @@ def bind_to_subparsers(subparsers: argparse._SubParsersAction, parent_parser: ar
                                               help="filter assets")
     filter_arg_parser.add_argument("-p", '--cis', dest="in_cis", type=str, default='', help="type names")
     filter_arg_parser.add_argument("-P", '--ex-cis', dest="ex_cis", type=str, default='', help="exclusive type names")
+    filter_arg_parser.add_argument(
+        '--filter-anno-src',
+        dest='filter_anno_src',
+        type=str,
+        default='any',
+        choices=['any', 'gt', 'pred'],
+        help="gt to filter class ids from ground truth, pred from prediction, any from both of them")
     filter_arg_parser.add_argument("--src-revs", dest="src_revs", type=str, help="type:rev@bid")
     filter_arg_parser.add_argument("--dst-rev", dest="dst_rev", type=str, help="rev@tid")
     filter_arg_parser.add_argument('-w', dest='work_dir', type=str, required=False, help='working directory')
