@@ -44,13 +44,22 @@ def parse_anno_format(anno_format_str: str) -> "mirpb.ExportFormat.V":
     return _anno_dict.get(anno_format_str.lower(), mirpb.ExportFormat.EF_NO_ANNOTATIONS)
 
 
-def parse_anno_type(anno_type_str: str) -> "mirpb.ObjectType.V":
+def parse_object_type(object_type_str: str) -> "mirpb.ObjectType.V":
     _anno_dict: Dict[str, "mirpb.ObjectType.V"] = {
         "det-box": mirpb.ObjectType.OT_DET_BOX,
         "seg": mirpb.ObjectType.OT_SEG,
         "no-annotations": mirpb.ObjectType.OT_NO_ANNOTATIONS,
     }
-    return _anno_dict.get(anno_type_str.lower(), mirpb.ObjectType.OT_UNKNOWN)
+    return _anno_dict.get(object_type_str.lower(), mirpb.ObjectType.OT_UNKNOWN)
+
+
+def anno_type_from_str(anno_type_str: str) -> "mirpb.AnnotationType.V":
+    enum_dict = {
+        'pred': mirpb.AnnotationType.AT_PRED,
+        'gt': mirpb.AnnotationType.AT_GT,
+        'any': mirpb.AnnotationType.AT_ANY,
+    }
+    return enum_dict.get(anno_type_str.lower(), mirpb.AnnotationType.AT_ANY)
 
 
 def _annotation_parse_func(anno_type: "mirpb.ObjectType.V") -> Callable:
@@ -96,7 +105,7 @@ def _voc_object_dict_to_annotation(object_dict: dict, cid: int,
         annotation.box.h = height
         annotation.box.rotate_angle = float(bndbox_dict.get('rotate_angle', '0.0'))
     else:
-        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_ARGS, error_message='no value for bndbox')
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET, error_message='no value for bndbox')
     return annotation
 
 
@@ -283,20 +292,24 @@ def import_annotations_coco_json(file_name_to_asset_ids: Dict[str, str], mir_ann
     add_if_not_found = (unknown_types_strategy == UnknownTypesStrategy.ADD)
 
     coco_file_path = os.path.join(annotations_dir_path, coco_json_filename)
-    with open(coco_file_path, 'r') as f:
-        coco_obj = json.loads(f.read())
-        images_list = coco_obj['images']
-        categories_list = coco_obj['categories']
-        annotations_list = coco_obj['annotations']
+    try:
+        with open(coco_file_path, 'r') as f:
+            coco_obj = json.loads(f.read())
+            images_list = coco_obj['images']
+            categories_list = coco_obj['categories']
+            annotations_list = coco_obj['annotations']
+    except (FileNotFoundError, json.JSONDecodeError) as e:
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET,
+                              error_message=f"Can not open or parse annotation file, {e}")
 
     if not images_list or not isinstance(images_list, list):
-        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_FILE,
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET,
                               error_message=f"Can not find images list in coco json: {coco_file_path}")
     if not isinstance(categories_list, list):
-        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_FILE,
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET,
                               error_message=f"Can not find categories list in coco json: {coco_file_path}")
     if not isinstance(annotations_list, list):
-        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_FILE,
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET,
                               error_message=f"Can not find annotations list in coco json: {coco_file_path}")
 
     unhashed_filenames_cnt = 0
@@ -378,7 +391,7 @@ def _import_annotation_meta(class_type_manager: class_ids.UserLabels, annotation
     except Exception:
         annotation_meta_dict = None
     if not isinstance(annotation_meta_dict, dict):
-        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_META_YAML_FILE,
+        raise MirRuntimeError(error_code=MirCode.RC_CMD_INVALID_DATASET,
                               error_message='Invalid meta.yaml')
 
     # model
